pub enum UserNoticeId {
Sub,
Resub,
Subgift,
SubMysteryGift,
GiftPaidUpgrade,
RewardGift,
AnonGiftPaidUpgrade,
Raid,
Unraid,
Ritual,
BitsBadgeTier,
Unknown,
}Expand description
The type of notice
Variants
Sub
A subscription event
Resub
A resubscription event
Subgift
A gift subscription event
SubMysteryGift
A mass subscription event occurs.
GiftPaidUpgrade
A gifted subscription is continued
RewardGift
Monetary event triggered emotes to be shared
AnonGiftPaidUpgrade
A gifted subscription from an anonymous user is continued
Raid
A raid happens
Unraid
A raid from the channel to another is cancelled.
Ritual
👎Deprecated
BitsBadgeTier
A user shares a new bits badge
Unknown
Unknown notice